@@ -239,12 +239,6 @@ import {
         if ( typeof hs[key] !== typeof hsDefault[key] ) { continue; }
         this.hiddenSettings[key] = hs[key];
     }
-    if ( typeof this.hiddenSettings.suspendTabsUntilReady === 'boolean' ) {
-        this.hiddenSettings.suspendTabsUntilReady =
-            this.hiddenSettings.suspendTabsUntilReady
-                ? 'yes'
-                : 'unset';
-    }
     this.fireDOMEvent('hiddenSettingsChanged');
 };
 
@@ -629,8 +623,9 @@ self.addEventListener('hiddenSettingsChanged', ( ) => {
 
     // User filter list.
     newAvailableLists[this.userFiltersPath] = {
+        content: 'filters',
         group: 'user',
-        title: vAPI.i18n('1pPageName')
+        title: vAPI.i18n('1pPageName'),
     };
 
     // Custom filter lists.
@@ -650,7 +645,8 @@ self.addEventListener('hiddenSettingsChanged', ( ) => {
         io.registerAssetSource(listKey, entry);
     }
 
-    // Convert a no longer existing stock list into an imported list.
+    // Convert a no longer existing stock list into an imported list, except
+    // when the removed stock list is deemed a "bad list".
     const customListFromStockList = assetKey => {
         const oldEntry = oldAvailableLists[assetKey];
         if ( oldEntry === undefined || oldEntry.off === true ) { return; }
@@ -658,6 +654,7 @@ self.addEventListener('hiddenSettingsChanged', ( ) => {
         if ( Array.isArray(listURL) ) {
             listURL = listURL[0];
         }
+        if ( this.badLists.has(listURL) ) { return; }
         const newEntry = {
             content: 'filters',
             contentURL: listURL,
@@ -810,7 +807,9 @@ self.addEventListener('hiddenSettingsChanged', ( ) => {
     const onFilterListsReady = function(lists) {
         this.availableFilterLists = lists;
 
-        vAPI.net.suspend();
+        if ( vAPI.Net.canSuspend() ) {
+            vAPI.net.suspend();
+        }
         redirectEngine.reset();
         staticExtFilteringEngine.reset();
         staticNetFilteringEngine.reset();
@@ -937,7 +936,7 @@ self.addEventListener('hiddenSettingsChanged', ( ) => {
             if ( matches[2] !== undefined ) {
                 updateAfter = Math.ceil(updateAfter / 24);
             }
-            updateAfter = Math.max(updateAfter, 1);
+            updateAfter = Math.max(updateAfter, 0.5);
             if ( updateAfter !== listEntry.updateAfter ) {
                 listEntry.updateAfter = updateAfter;
                 io.registerAssetSource(assetKey, { updateAfter });
@@ -979,6 +978,8 @@ self.addEventListener('hiddenSettingsChanged', ( ) => {
 
     parser.setMaxTokenLength(staticNetFilteringEngine.MAX_TOKEN_LENGTH);
 
+    compiler.start(writer);
+
     while ( lineIter.eot() === false ) {
         let line = lineIter.next();
 
@@ -1013,6 +1014,8 @@ self.addEventListener('hiddenSettingsChanged', ( ) => {
         }
     }
 
+    compiler.finish(writer);
+
     // https://github.com/uBlockOrigin/uBlock-issues/issues/1365
     //   Embed version into compiled list itself: it is encoded in as the
     //   first digits followed by a whitespace.
@@ -1491,7 +1494,7 @@ self.addEventListener('hiddenSettingsChanged', ( ) => {
 /******************************************************************************/
 
 // https://github.com/gorhill/uBlock/issues/2344
-//   Support mutliple locales per filter list.
+//   Support multiple locales per filter list.
 // https://github.com/gorhill/uBlock/issues/3210
 //   Support ability to auto-enable a filter list based on user agent.
 // https://github.com/gorhill/uBlock/pull/3860
